@@ -227,7 +227,7 @@ class Vertex:
     def __init__(
         self,
         name: str,
-        colo: Optional["Vertex"],
+        extends: Optional["Vertex"],
         extra_cols: List[Column],
         entry_point: Optional[Column],
         data_keys: List[str],
@@ -235,7 +235,7 @@ class Vertex:
         drop: bool,
     ) -> None:
         assert isinstance(name, str)
-        assert colo is None or isinstance(colo, Vertex)
+        assert extends is None or isinstance(extends, Vertex)
         assert isinstance(extra_cols, list)
         if extra_cols:
             for extra_col in extra_cols:
@@ -256,20 +256,20 @@ class Vertex:
 
         self.name = name
         self.table_name = '{}."{}"'.format(SCHEMA_NAME, self.name)
-        self.colo = colo
+        self.extends = extends
         self.cols = self.base_cols + extra_cols
         self.extra_cols = extra_cols
         self.entry_point = entry_point
         self.data_keys = data_keys
         self.indexes = indexes
         self.drop = drop
-        # The vertices that reference this as their colo buddy.
-        self.colo_backrefs: List[Vertex] = []
+        # The vertices that reference this as their extends source.
+        self.extends_backrefs: List[Vertex] = []
         # The counters that reference an edge with this vertex as source.
         self.counter_backrefs: List[Counter] = []
 
-    def add_colo_backref(self, backref: "Vertex") -> None:
-        self.colo_backrefs.append(backref)
+    def add_extends_backref(self, backref: "Vertex") -> None:
+        self.extends_backrefs.append(backref)
 
     def add_counter_backref(self, backref: "Counter") -> None:
         self.counter_backrefs.append(backref)
@@ -277,7 +277,7 @@ class Vertex:
     def __repr__(self) -> str:
         return "Vertex({!r}, {!r}, {!r}, {!r}, {!r}, {!r}".format(
             self.name,
-            self.colo,
+            self.extends,
             self.cols,
             self.entry_point,
             self.data_keys,
@@ -285,7 +285,7 @@ class Vertex:
         )
 
     def has_colos(self) -> bool:
-        if self.colo is not None:
+        if self.extends is not None:
             return True
         else:
             for col in self.cols:
@@ -300,13 +300,13 @@ class Vertex:
         for col in self.base_cols:
             tbl_stmt += "  {},\n".format(col.decl())
         tbl_stmt += "  PRIMARY KEY (gid),\n"
-        if self.colo is not None:
+        if self.extends is not None:
             tbl_stmt += "  FOREIGN KEY (gid) REFERENCES {} (gid),\n".format(
-                self.colo.table_name
+                self.extends.table_name
             )
         tbl_stmt += "  CHECK ((gid).id IS NOT NULL AND (gid).vshard IS NOT NULL)\n);"
         stmts = [tbl_stmt]
-        if self.colo is None:
+        if self.extends is None:
             seq_stmt = (
                 "CREATE SEQUENCE {0}.{1}_gid_id_seq OWNED BY {0}.{1}.gid;".format(
                     SCHEMA_NAME,
